@@ -19,7 +19,8 @@ import sunau
 import audioop
 import struct
 import sys
-from . import DecodeError
+
+from .exceptions import DecodeError
 
 # Produce two-byte (16-bit) output samples.
 TARGET_WIDTH = 2
@@ -40,7 +41,7 @@ class BitWidthError(DecodeError):
 
 
 def byteswap(s):
-    """Swaps the endianness of the bytesting s, which must be an array
+    """Swaps the endianness of the bytestring s, which must be an array
     of shorts (16-bit signed integers). This is probably less efficient
     than it should be.
     """
